#!/bin/sh
# SPDX-License-Identifier: MIT
# Copyright (C) 2019 Beckhoff Automation GmbH & Co. KG

. /usr/local/bin/shlib/add_or_replace_in.sh
. /usr/local/bin/shlib/std.sh

if [ $(id -u) -ne 0 ]; then
	throw "Usage: run '$0' as root.\n"
fi

env ASSUME_ALWAYS_YES=YES pkg install \
	xorg-minimal \
	drm-kmod \
	plasma5-plasma \
	kate \
	konsole \
	sddm \
	plasma5-sddm-kcm \
	firefox

# set full username for login-managers
pw usermod Administrator -c "Administrator"

# configure driver, login and window manager
pw groupmod video -m Administrator

add_or_replace_in /usr/local/etc/sddm.conf 'Current=' 'breeze'
add_or_replace_in /etc/sysctl.conf 'kern.evdev.rcpt_mask=' '6'
sysrc -f /etc/rc.conf dbus_enable=YES
sysrc -f /etc/rc.conf sddm_enable=YES
sysrc -f /etc/rc.conf webcamd_enable=YES
sysrc -f /boot/loader.conf cuse_load=YES
sysrc -f /etc/rc.conf kld_list+=/boot/modules/i915kms.ko

# use german keyboard layout within X
cat << EOF > /usr/local/etc/X11/xorg.conf.d/13-keyboard-evdev.conf

Section "InputClass"
	Identifier "KeyboardEvdev"
	MatchIsKeyboard "on"
	Option "XkbRules" "evdev"
EndSection

EOF

cat << EOF > /usr/local/etc/X11/xorg.conf.d/94-keyboard-de.conf

Section "InputClass"
	Identifier "KeyboardLayout"
	MatchIsKeyboard "on"
	Option "XkbLayout" "de"
EndSection

EOF

# remove potential old keyboard config
rm /usr/local/etc/X11/xorg.conf.d/keyboard-de.conf

# disable baloo for better performance on low-end devices
su -l Administrator -c "balooctl disable"

# enable virtualbox additions if we detect virtualbox
if sysctl -a | grep VBOX; then
	/bin/sh /usr/local/share/examples/bhf/enable-vboxguest.sh
fi

# and start ...
sysctl -w kern.evdev.rcpt_mask=6
kldload /boot/modules/i915kms.ko
kldload cuse
service devd restart
service dbus start
service sddm start
